@@ -17,6 +17,13 @@ def poisson(filter_extent, search_extent=None):
             "search_extent": search_extent, "filter_extent": filter_extent}
 
 
+def loupas(filter_extent, search_extent=None):
+    if search_extent is None:
+        search_extent = filter_extent
+    return {"name": "loupas",
+            "search_extent": search_extent, "filter_extent": filter_extent}
+
+
 def ttest(filter_extent, search_extent=None):
     if search_extent is None:
         search_extent = filter_extent
