@@ -111,6 +111,8 @@ def format_method(t):
             base = "Ours (Gaussian, const. $\\sigma$)"
     elif "poisson" in name:
         base = "Ours (Poisson)"
+    elif "loupas" in name:
+        base = "Ours (Loupas)"
     elif "ttest" in name:
         base = "Bian [5] (Gaussian, var. $\\sigma$)"
 
