@@ -6,9 +6,19 @@ import scipy.ndimage
 import scipy.spatial
 import sklearn.metrics
 import matplotlib.pyplot as plt
+
 # Note: you first have to build and install the package in the repository root!
+
+# If you do not want to install, or for local development uncomment the
+# following lines to directly use the files in the repository. The shared
+# library has to be located in a subfolder "lib".
+
+#import sys
+#from os import path
+#project_folder_path = path.join(path.dirname(path.abspath(__file__)), "..", "..")
+#sys.path.append(project_folder_path)
 import rw_noise
-from rw_noise import fixed, poisson, ttest, global_gaussian_bian, global_gaussian, variable_gaussian
+from rw_noise import fixed, poisson, ttest, global_gaussian_bian, global_gaussian, variable_gaussian, loupas
 
 run_rw_with_weights = rw_noise.solve
 rw_weights = rw_noise.weights
